@@ -1,6 +1,6 @@
 package App::MysqlUtils;
 
-use 5.010001;
+use 5.034; # uses new octal notation 0o123
 use strict;
 use warnings;
 use Log::ger;
@@ -12,9 +12,9 @@ use Perinci::Object;
 use String::ShellQuote;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-12'; # DATE
+our $DATE = '2022-10-19'; # DATE
 our $DIST = 'App-MysqlUtils'; # DIST
-our $VERSION = '0.021'; # VERSION
+our $VERSION = '0.022'; # VERSION
 
 our %SPEC;
 
@@ -1124,7 +1124,7 @@ App::MysqlUtils - CLI utilities related to MySQL
 
 =head1 VERSION
 
-This document describes version 0.021 of App::MysqlUtils (from Perl distribution App-MysqlUtils), released on 2022-10-12.
+This document describes version 0.022 of App::MysqlUtils (from Perl distribution App-MysqlUtils), released on 2022-10-19.
 
 =head1 SYNOPSIS
 
@@ -1234,12 +1234,16 @@ Currently the choices are:
 
 =item * B<database>* => I<str>
 
+(No description)
+
 =item * B<from>* => I<str>
 
 Name of source table.
 
 =item * B<host> => I<str> (default: "localhost")
 
+(No description)
+
 =item * B<password> => I<str>
 
 Will try to get default from C<~/.my.cnf>.
@@ -1250,6 +1254,8 @@ Name of PK column.
 
 =item * B<port> => I<int> (default: 3306)
 
+(No description)
+
 =item * B<to>* => I<str>
 
 Name of target table.
@@ -1306,14 +1312,20 @@ Arguments ('*' denotes required arguments):
 
 =item * B<database>* => I<str>
 
+(No description)
+
 =item * B<host> => I<str> (default: "localhost")
 
+(No description)
+
 =item * B<password> => I<str>
 
 Will try to get default from C<~/.my.cnf>.
 
 =item * B<port> => I<int> (default: 3306)
 
+(No description)
+
 =item * B<username> => I<str>
 
 Will try to get default from C<~/.my.cnf>.
@@ -1377,10 +1389,16 @@ Arguments ('*' denotes required arguments):
 
 =item * B<db_pattern> => I<re>
 
+(No description)
+
 =item * B<dbs> => I<array[str]>
 
+(No description)
+
 =item * B<host> => I<str> (default: "localhost")
 
+(No description)
+
 =item * B<limit> => I<posint>
 
 Don't delete more than this number of databases.
@@ -1391,6 +1409,8 @@ Will try to get default from C<~/.my.cnf>.
 
 =item * B<port> => I<int> (default: 3306)
 
+(No description)
+
 =item * B<username> => I<str>
 
 Will try to get default from C<~/.my.cnf>.
@@ -1454,8 +1474,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<database>* => I<str>
 
+(No description)
+
 =item * B<host> => I<str> (default: "localhost")
 
+(No description)
+
 =item * B<limit> => I<posint>
 
 Don't delete more than this number of tables.
@@ -1466,10 +1490,16 @@ Will try to get default from C<~/.my.cnf>.
 
 =item * B<port> => I<int> (default: 3306)
 
+(No description)
+
 =item * B<table_pattern> => I<re>
 
+(No description)
+
 =item * B<tables> => I<array[str]>
 
+(No description)
+
 =item * B<username> => I<str>
 
 Will try to get default from C<~/.my.cnf>.
@@ -1535,6 +1565,8 @@ Instead of returning the CSV rows, just return the count of rows that get filled
 
 =item * B<database>* => I<str>
 
+(No description)
+
 =item * B<escape_char> => I<str>
 
 Specify character to escape value in field in input CSV, will be passed to Text::CSV_XS.
@@ -1557,14 +1589,20 @@ and so on.
 
 =item * B<host> => I<str> (default: "localhost")
 
+(No description)
+
 =item * B<password> => I<str>
 
 Will try to get default from C<~/.my.cnf>.
 
 =item * B<port> => I<int> (default: 3306)
 
+(No description)
+
 =item * B<query>* => I<str>
 
+(No description)
+
 =item * B<quote_char> => I<str>
 
 Specify field quote character in input CSV, will be passed to Text::CSV_XS.
@@ -1630,18 +1668,24 @@ Arguments ('*' denotes required arguments):
 
 =item * B<database>* => I<str>
 
+(No description)
+
 =item * B<exclude_columns> => I<array[str]>
 
 What column(s) to exclude from comparison.
 
 =item * B<host> => I<str> (default: "localhost")
 
+(No description)
+
 =item * B<password> => I<str>
 
 Will try to get default from C<~/.my.cnf>.
 
 =item * B<port> => I<int> (default: 3306)
 
+(No description)
+
 =item * B<return_column>* => I<str>
 
 What column to return.
@@ -1711,16 +1755,24 @@ Add first field containing number from 1, 2, ...
 
 =item * B<database>* => I<str>
 
+(No description)
+
 =item * B<host> => I<str> (default: "localhost")
 
+(No description)
+
 =item * B<password> => I<str>
 
 Will try to get default from C<~/.my.cnf>.
 
 =item * B<port> => I<int> (default: 3306)
 
+(No description)
+
 =item * B<query>* => I<str>
 
+(No description)
+
 =item * B<username> => I<str>
 
 Will try to get default from C<~/.my.cnf>.
@@ -1760,6 +1812,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<database>* => I<str>
 
+(No description)
+
 =item * B<directory> => I<dirname> (default: ".")
 
 Specify directory for the resulting *.txt files.
@@ -1778,6 +1832,8 @@ always overwrite existing .txt file.
 
 =item * B<pl_files>* => I<array[filename]>
 
+(No description)
+
 
 =back
 
@@ -1810,6 +1866,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<database>* => I<str>
 
+(No description)
+
 =item * B<directory> => I<dirname> (default: ".")
 
 Specify directory for the resulting *.txt files.
@@ -1828,6 +1886,8 @@ always overwrite existing .txt file.
 
 =item * B<sql_files>* => I<array[filename]>
 
+(No description)
+
 
 =back
 
@@ -1864,18 +1924,32 @@ Directory to put the SQL files into.
 
 =item * B<exclude_table_patterns> => I<array[re]>
 
+(No description)
+
 =item * B<exclude_tables> => I<array[str]>
 
+(No description)
+
 =item * B<include_table_patterns> => I<array[re]>
 
+(No description)
+
 =item * B<include_tables> => I<array[str]>
 
+(No description)
+
 =item * B<overwrite> => I<bool>
 
+(No description)
+
 =item * B<stop_after_table> => I<str>
 
+(No description)
+
 =item * B<stop_after_table_pattern> => I<re>
 
+(No description)
+
 
 =back
 
